..
    Copyright (C) 2020 CERN.

    Invenio-Banners is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.


.. include:: ../CONTRIBUTING.rst
